#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  ../../COPYING


################################################################################
# FUNCTION:                 COLUMN STATISTICS IN FUTILITIES:
#  rank.timeSeries           Returns sample ranks of a timeSeries object.
################################################################################

setMethod("rank", "timeSeries",
          function(x,  na.last = TRUE,
                   ties.method = c("average", "first", "random", "max", "min"))
          apply(x, 2, rank, na.last = na.last, ties.method = ties.method))

################################################################################

